@@ -127,7 +127,6 @@ ordered_clauses = [
 
 class Formatter:
     # infix operators
-    _concat = Operator("||")
     _mul = Operator("*")
     _div = Operator("/")
     _mod = Operator("%")
@@ -205,8 +204,7 @@ class Formatter:
             parts.append("OVER")
             window = []
             if "partitionby" in over:
-                window.append("PARTITION BY")
-                window.append(self.dispatch(over["partitionby"]))
+                window.append(self.partitionby(over, precedence["window"]))
             if "orderby" in over:
                 window.append(self.orderby(over, precedence["window"]))
             if "range" in over:
@@ -550,6 +548,12 @@ class Formatter:
         )
         return f"ORDER BY {param}"
 
+    def partitionby(self, json, prec):
+        param = ", ".join(
+            self.dispatch(s, precedence["order"]) for s in listwrap(json["partitionby"])
+        )
+        return f"PARTITION BY {param}"
+
     def limit(self, json, prec):
         num = self.dispatch(json["limit"], precedence["order"])
         return f"LIMIT {num}"
