@@ -91,7 +91,8 @@ LT = Literal("<").set_parser_name("lt")
 GT = Literal(">").set_parser_name("gt")
 EEQ = (
     # conservative equality  https://github.com/klahnakoski/jx-sqlite/blob/dev/docs/Logical%20Equality.md#definitions
-    Literal("==") | Literal("=")
+    Literal("==")
+    | Literal("=")
 ).set_parser_name("eq")
 DEQ = (
     # decisive equality
@@ -112,6 +113,7 @@ NEQ = (Literal("!=") | Literal("<>")).set_parser_name("neq")
 LAMBDA = Literal("->").set_parser_name("lambda")
 
 AND = keyword("and")
+APPLY = keyword("apply")
 BETWEEN = keyword("between")
 CASE = keyword("case").suppress()
 COLLATE = keyword("collate")
@@ -129,11 +131,14 @@ VIEW = keyword("view")
 
 joins = (
     (
-        Optional(CROSS | OUTER | INNER | ((FULL | LEFT | RIGHT) + Optional(INNER | OUTER)))
+        Optional(
+            CROSS | OUTER | INNER | ((FULL | LEFT | RIGHT) + Optional(INNER | OUTER))
+        )
         + JOIN
         + Optional(LATERAL)
     )
     | LATERAL + VIEW + Optional(OUTER)
+    | (CROSS | OUTER) + APPLY
 ) / (lambda tokens: " ".join(tokens).lower())
 
 UNION_ALL = (UNION + ALL).set_parser_name("union_all")
@@ -237,6 +242,8 @@ join_keywords = {
     "full outer join",
     "right outer join",
     "left outer join",
+    "cross apply",
+    "outer apply",
 }
 
 precedence = {
