@@ -12,6 +12,7 @@ from mo_parsing.helpers import restOfLine
 from mo_parsing.infix import delimited_list
 from mo_parsing.whitespaces import NO_WHITESPACE, Whitespace
 
+from mo_sql_parsing import utils
 from mo_sql_parsing.keywords import *
 from mo_sql_parsing.types import get_column_type, time_functions
 from mo_sql_parsing.utils import *
@@ -46,6 +47,8 @@ def common_parser():
 
 
 def mysql_parser():
+    utils.emit_warning_for_double_quotes = False
+
     mysql_string = ansi_string | mysql_doublequote_string
     mysql_ident = Combine(delimited_list(
         mysql_backtick_ident | sqlserver_ident | simple_ident,
@@ -76,6 +79,7 @@ def parser(literal_string, ident, sqlserver=False):
         engine.add_ignore(Literal("/*") + SkipTo("*/", include=True))
 
         var_name = ~RESERVED + ident
+        func_name = ~FROM + ident
 
         # EXPRESSIONS
         expr = Forward()
@@ -229,7 +233,7 @@ def parser(literal_string, ident, sqlserver=False):
         query = Forward().set_parser_name("query")
 
         call_function = (
-            ident("op")
+            func_name("op")
             + LB
             + Optional(Group(query) | delimited_list(Group(expr)))("params")
             + Optional(
@@ -411,6 +415,7 @@ def parser(literal_string, ident, sqlserver=False):
         table_source << Group(
             ((LB + query + RB) | stack | call_function | var_name)("value")
             + Optional(flag("with ordinality"))
+            + Optional(WITH + LB + keyword("nolock")("hint") + RB)
             + Optional(tablesample)
             + alias
         ).set_parser_name("table_source") / to_table
@@ -571,6 +576,8 @@ def parser(literal_string, ident, sqlserver=False):
             keyword("drop index") + Optional(flag("if exists")) + var_name("index")
         )("drop")
 
+        returning = Optional(delimited_list(select_column)("returning"))
+
         insert = (
             keyword("insert").suppress()
             + (
@@ -581,6 +588,7 @@ def parser(literal_string, ident, sqlserver=False):
             + Optional(LB + delimited_list(var_name)("columns") + RB)
             + Optional(flag("if exists"))
             + (values | query)("query")
+            + returning
         ) / to_insert_call
 
         update = (
@@ -588,6 +596,7 @@ def parser(literal_string, ident, sqlserver=False):
             + var_name("params")
             + assign("set", Dict(delimited_list(Group(var_name + EQ + expr))))
             + Optional(assign("where", expr))
+            + returning
         ) / to_json_call
 
         delete = (
@@ -595,6 +604,7 @@ def parser(literal_string, ident, sqlserver=False):
             + keyword("from").suppress()
             + var_name("params")
             + Optional(assign("where", expr))
+            + returning
         ) / to_json_call
 
         return (
